@@ -175,7 +175,7 @@ class Manager(object):
         if self.initialized:
             raise RuntimeError('Cannot call initialize on an already initialized manager.')
 
-        plugin.load_plugins()
+        plugin.load_plugins(extra_dirs=[os.path.join(self.config_base, 'plugins')])
 
         # Reparse CLI options now that plugins are loaded
         self.options = get_parser().parse_args(self.args)
@@ -236,19 +236,23 @@ class Manager(object):
         task_names = self.tasks
         # Handle --tasks
         if options.tasks:
-            # Create list of tasks to run, preserving order
-            task_names = []
-            for arg in options.tasks:
-                matches = [t for t in self.tasks if fnmatch.fnmatchcase(unicode(t).lower(), arg.lower())]
-                if not matches:
-                    msg = '`%s` does not match any tasks' % arg
-                    log.error(msg)
-                    if output:
-                        output.write(msg)
-                    continue
-                task_names.extend(m for m in matches if m not in task_names)
-            # Set the option as a list of matching task names so plugins can use it easily
-            options.tasks = task_names
+            # Consider * the same as not specifying tasks at all (makes sure manual plugin still works)
+            if options.tasks == ['*']:
+                options.tasks = None
+            else:
+                # Create list of tasks to run, preserving order
+                task_names = []
+                for arg in options.tasks:
+                    matches = [t for t in self.tasks if fnmatch.fnmatchcase(unicode(t).lower(), arg.lower())]
+                    if not matches:
+                        msg = '`%s` does not match any tasks' % arg
+                        log.error(msg)
+                        if output:
+                            output.write(msg)
+                        continue
+                    task_names.extend(m for m in matches if m not in task_names)
+                # Set the option as a list of matching task names so plugins can use it easily
+                options.tasks = task_names
         # TODO: 1.2 This is a hack to make task priorities work still, not sure if it's the best one
         task_names = sorted(task_names, key=lambda t: self.config['tasks'][t].get('priority', 65535))
 
@@ -527,6 +531,7 @@ class Manager(object):
         self.lockfile = os.path.join(self.config_base, '.%s-lock' % self.config_name)
         self.db_filename = os.path.join(self.config_base, 'db-%s.sqlite' % self.config_name)
 
+
     def load_config(self):
         """
         Loads the config file from disk, validates and activates it.
