@@ -4,9 +4,11 @@ import time
 import logging
 from datetime import timedelta, datetime
 from urlparse import urlparse
+
 import requests
 # Allow some request objects to be imported from here instead of requests
 from requests import RequestException, HTTPError
+
 from flexget import __version__ as version
 from flexget.utils.tools import parse_timedelta, TimedDict
 
@@ -46,6 +48,21 @@ def set_unresponsive(url):
     unresponsive_hosts[host] = True
 
 
+def wait_for_domain(url, delay_dict):
+    for domain, domain_dict in delay_dict.iteritems():
+        if domain in url:
+            next_req = domain_dict.get('next_req')
+            if next_req and datetime.now() < next_req:
+                wait_time = next_req - datetime.now()
+                seconds = wait_time.seconds + (wait_time.microseconds / 1000000.0)
+                log.debug('Waiting %.2f seconds until next request to %s' % (seconds, domain))
+                # Sleep until it is time for the next request
+                time.sleep(seconds)
+            # Record the next allowable request time for this domain
+            domain_dict['next_req'] = datetime.now() + domain_dict['delay']
+            break
+
+
 def _wrap_urlopen(url, timeout=None):
     """
     Handles alternate schemes using urllib, wraps the response in a requests.Response
@@ -115,19 +132,8 @@ class Session(requests.Session):
         if is_unresponsive(url):
             raise requests.Timeout('Requests to this site have timed out recently. Waiting before trying again.')
 
-        # Check if we need to add a delay before request to this site
-        for domain, domain_dict in self.domain_delay.iteritems():
-            if domain in url:
-                next_req = domain_dict.get('next_req')
-                if next_req and datetime.now() < next_req:
-                    wait_time = next_req - datetime.now()
-                    seconds = wait_time.seconds + (wait_time.microseconds / 1000000.0)
-                    log.debug('Waiting %.2f seconds until next request to %s' % (seconds, domain))
-                    # Sleep until it is time for the next request
-                    time.sleep(seconds)
-                # Record the next allowable request time for this domain
-                domain_dict['next_req'] = datetime.now() + domain_dict['delay']
-                break
+        # Delay, if needed, before another request to this site
+        wait_for_domain(url, self.domain_delay)
 
         kwargs.setdefault('timeout', self.timeout)
         raise_status = kwargs.pop('raise_status', True)
